@@ -5,6 +5,7 @@ package Sim::OPT::Report;
 # The content of this module is stale. It has to be entirely re-checked.
 
 use v5.14;
+# use v5.20;
 use Exporter;
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
 use Math::Trig;
@@ -27,8 +28,12 @@ use Data::Dumper;
 #$Data::Dumper::Useqq  = 1;
 #$Data::Dumper::Terse  = 1;
 use Data::Dump qw(dump);
-use Sub::Signatures;
 use feature 'say';
+#use feature qw(postderef);
+#no warnings qw(experimental::postderef);
+#use Sub::Signatures;
+#no warnings qw(Sub::Signatures); 
+#no strict 'refs';
 no strict; 
 no warnings;
 
